@@ -277,8 +277,12 @@ def parse_args(action, default_db, default_chromecast=""):
     if args.db:
         args.database = args.db
 
-    if not args.limit and all([not args.print, args.action in [SC.listen, SC.watch, SC.tubelisten, SC.tubewatch]]):
+    if not args.limit and all(
+        [not args.print, args.action in [SC.listen, SC.watch, SC.tubelisten, SC.tubewatch, SC.read]]
+    ):
         args.limit = utils.DEFAULT_PLAY_QUEUE
+    if not args.limit and all([not args.print, args.action in [SC.view]]):
+        args.limit = utils.DEFAULT_PLAY_QUEUE * 4
     elif args.limit in ["inf", "all"]:
         args.limit = None
 
@@ -613,10 +617,11 @@ def construct_fs_query(args):
     query = f"""SELECT path
         , size
         {', duration' if args.action in [SC.listen, SC.watch] else ''}
+        {', cast(length(tags) / 4.2 / 220 * 60 as INT) + 10 duration' if args.action == SC.read else ''}
         {', subtitle_count' if args.action == SC.watch else ''}
         {', sparseness' if args.action == SC.filesystem else ''}
         {', is_dir' if args.action == SC.filesystem else ''}
-        {', ' + ', '.join(args.cols) if args.cols else ''}
+        {', ' + ', '.join(args.cols) if args.cols and args.cols != ['duration'] else ''}
     FROM {args.table}
     WHERE 1=1
     {args.sql_filter}
@@ -677,3 +682,13 @@ def listen():
 def filesystem():
     args = parse_args(SC.filesystem, "fs.db")
     process_playqueue(args)
+
+
+def read():
+    args = parse_args(SC.read, "text.db")
+    process_playqueue(args)
+
+
+def view():
+    args = parse_args(SC.view, "image.db")
+    process_playqueue(args)
