@@ -303,6 +303,13 @@ def socket_play(args, m):
     sleep(args.interdimensional_cable)
 
 
+def find_xdg_application(media_file):
+    mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
+    default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
+    player_path = which(default_application.replace(".desktop", ""))
+    return player_path
+
+
 def local_player(args, m, media_file):
     player = generic_player(args)
     mpv = which("mpv.com") or which("mpv")
@@ -311,6 +318,11 @@ def local_player(args, m, media_file):
         player = args.player
         args.player_need_sleep = False
 
+    elif args.action in [SC.read]:
+        player_path = find_xdg_application(media_file)
+        log.info(player_path)
+        pass
+
     elif mpv:
         args.player_need_sleep = False
         player = [mpv]
@@ -340,9 +352,7 @@ def local_player(args, m, media_file):
                 player.extend(args.player_args_no_sub)
 
     elif system() == "Linux":
-        mimetype = cmd("xdg-mime", "query", "filetype", media_file).stdout
-        default_application = cmd("xdg-mime", "query", "default", mimetype).stdout
-        player_path = which(default_application.replace(".desktop", ""))
+        player_path = find_xdg_application(media_file)
         if player_path:
             args.player_need_sleep = False
             player = [player_path]
@@ -368,7 +378,8 @@ def printer(args, query, bindings):
     if "a" in args.print:
         query = f"""select
             "Aggregate" as path
-            {', sum(duration) duration' if args.action in [SC.listen, SC.watch, SC.tubelisten, SC.tubewatch] else ''}
+            {', sum(duration) duration' if args.action in [SC.listen, SC.watch, SC.tubelisten, SC.tubewatch, SC.read] else ''}
+            {', avg(duration) avg_duration' if args.action in [SC.listen, SC.watch, SC.tubelisten, SC.tubewatch, SC.read] else ''}
             {', sparseness' if args.action == SC.filesystem else ''}
             {', sum(size) size' if args.action != SC.tabs else ''}
             , count(*) count
@@ -430,6 +441,7 @@ def printer(args, query, bindings):
 
         utils.col_naturalsize(tbl, "size")
         utils.col_duration(tbl, "duration")
+        utils.col_duration(tbl, "avg_duration")
 
         for t in [
             "time_modified",
